@@ -170,6 +170,8 @@ fn build(opts: &crate::Dylint, toolchain: &str, driver: &Path) -> Result<()> {
         toolchain,
         consts::EXE_SUFFIX
     ));
+    #[allow(unknown_lints)]
+    #[allow(nonreentrant_function_in_test)]
     copy(&binary, driver).with_context(|| {
         format!(
             "Could not copy `{}` to `{}`",
@@ -181,6 +183,9 @@ fn build(opts: &crate::Dylint, toolchain: &str, driver: &Path) -> Result<()> {
     Ok(())
 }
 
+// smoelius: `package` is a temporary directory. So there should be no race here.
+#[allow(unknown_lints)]
+#[allow(nonreentrant_function_in_test)]
 fn initialize(toolchain: &str, package: &Path) -> Result<()> {
     let version_spec = format!("version = \"={}\"", env!("CARGO_PKG_VERSION"));
 
