@@ -208,7 +208,7 @@ fn dependency_root(config: &Config, dep: &Dependency) -> Result<PathBuf> {
 
 #[allow(clippy::default_trait_access)]
 fn git_dependency_root(config: &Config, dep: &Dependency) -> Result<PathBuf> {
-    let _lock = config.acquire_package_cache_lock();
+    let _lock = config.acquire_package_cache_lock()?;
 
     let mut source = dep.source_id().load(config, &Default::default())?;
 
@@ -277,7 +277,10 @@ fn package_id(source_id: SourceId, package_root: &Path) -> Result<PackageId> {
         .first()
         .ok_or_else(|| anyhow!("Found no packages in `{}`", package_root.to_string_lossy()))?;
 
-    assert!(metadata.workspace_root == package.manifest_path.parent().unwrap());
+    assert_eq!(
+        metadata.workspace_root,
+        package.manifest_path.parent().unwrap()
+    );
 
     PackageId::new(&package.name, &package.version.to_string(), source_id)
 }
